package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0D```````````,``P`!````G!<``#0```!`L0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$```T````-````!`````$````!````````````````````#*T`
M``RM```%`````!````$```"HK0``J+T``*B]``!H`@``K`8```8`````$```
M`@```+"M``"PO0``L+T``"`!```@`0``!@````0````$````9`$``&0!``!D
M`0``1````$0````$````!````%#E=&1(GP``2)\``$B?``#L````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DJ*T`
M`*B]``"HO0``6`(``%@"```$`````0```"]L:6(O;&0N<V\N,0`````$````
M$`````$```!'3E4``P````@````#``````````0````4`````P```$=.50"M
MZ>B'8]RRX$&&@9!:08<!6,UN'Q$```!+````"`````@`````$!`$)4`$@"@!
M``&@A@"`@`$```LH!`DXH!)%B@0("`````!+````3P```%,```!4````6@``
M`%L```!<````7@```%\`````````80```&,`````````9```````````````
M;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5DU'S9<5@<XD?&`:Q+X\"Z
MXY)\PN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0PZ
MEPM9Z.WL?ZF<FZ/@^TD`````````````````````$P,`````````````$@``
M`)L"`````````````!(```!7`P`````````````2````#P(`````````````
M$@```!$``````````````"`````6`@`````````````2````>`(`````````
M````$@```%\"`````````````!(```"&`@`````````````2````M```````
M````````$@```(@!`````````````!(```!)`P`````````````2````A```
M````````````$@```!$!`````````````!(```"4`@`````````````2````
M:@,`````````````(0```',#`````````````!(````&`0`````````````1
M````;`$`````````````$@```.@``````````````!$````:`P``````````
M```2````.@$`````````````$@```,(``````````````!(```"V`0``````
M```````2````5P(`````````````$@```$`"`````````````!(```"C`0``
M```````````2````:P,`````````````$0```/4!`````````````!(```#E
M`@`````````````2````T@(`````````````$@```$@!`````````````!(`
M```&`P`````````````2````:`(`````````````$@````D"````````````
M`!(````M```````````````@````W0(`````````````$@```,$!````````
M`````!$```!D```````````````2````H@(`````````````$@```"0#````
M`````````"(```!0`P`````````````2````:0,`````````````$0```,4#
M`````````````!(```"3```````````````2````GP``````````````$@``
M`"\"`````````````!(```!A`0`````````````2````)P$`````````````
M$@```/8"`````````````!(```!6```````````````2````00,`````````
M````$@```!8!`````````````!(````;`0`````````````2````O0(`````
M````````$@```,0"`````````````!(```"8`0`````````````2````]0``
M````````````$@```*D"`````````````!(```!Z`0`````````````2````
M<P``````````````$@```'$"`````````````!(```!^`@`````````````2
M````V0``````````````$@```%@!`````````````!(```#O`@``````````
M```1````C0(`````````````$@```/T"`````````````!(````G`@``````
M```````2````KP(`````````````$@```#P``````````````"````"O`0``
M```````````2````4@(`````````````$@```#,#`````````````!(```#.
M`P``P%X``'8````2``X`G`,```1@````````$@`/`/H#``"`3P``MPL``!(`
M#@!D`P``4!4``$P"```2``X`H@,``.!(```#````$@`.`&4$``#P2```!0(`
M`!(`#@!?!```3!$````````2``L`D@0``$!;``!^`P``$@`.`%$$```0P```
M`````!``&`#A`P```$L``"D````2``X`%`0``!Q@```$````$0`0`-0```!4
MQ````````!``&`!=!```0$@``#L````2``X`<@0``+!.``#&````$@`.`(0$
M``#P30``=@```!(`#@`'!````,`````````0`!<`[@,``#!+``#H````$@`.
M`-H#```0P````````!``%P`S!```#,````0````1`!<`D@,``.!?```"````
M$@`.`",$``"`7P``70```!(`#@`-!```G!<````````2``X`"00```#`````
M````(``7`#T$```88```!````!$`$`"S`P``<$X``#<````2``X`1`0``"!,
M``#0`0``$@`.``!L:6)P97)L+G-O+C4N,C@`7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V5N
M9`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G
M<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C$`
M;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E
M;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N,"XQ
M`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S
M961I<@!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O
M:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?
M<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E
M<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I
M<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E
M<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W-T86-K
M7V-H:U]F86EL`&QI8F-R>7!T+G-O+C$`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``7V5D871A`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT
M;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`%]?;&EB8U]C<W5?
M:6YI=`!M>5]P87)?<&P`7V9P7VAW`'!A<E]I;FET7V5N=@!?7V)S<U]S=&%R
M=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C,`1TQ)
M0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`"``(``P````,`
M`@`"``(```````(```````(``@`$``````````(``````````@`%`````@`#
M``(``@````8``@`#`````@```````@`"``(``@`"```````#```````"````
M`@`"`````@`&```````"```````"``(```````(``@`"``,`!@````(``@`&
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0````$``0#E`0``$````"`````3:6D-```#`*@$`````````0`$
M`#0"```0`````````'09:0D```8`L@0``!````!R&6D)```%`+X$```0````
M%&EI#0``!`#*!```$````!-I:0T```(`J`0```````"HO0``"````*R]```(
M````\+\```@````$P```"`````S````(````S+\```8%``#0OP``!@L``-2_
M```&$@``V+\```84``#<OP``!AP``."_```&)```Y+\```8F``#HOP``!BD`
M`.R_```&,0``]+\```8]``#XOP``!D(``/R_```&1P``W+X```<!``#@O@``
M!P(``.2^```'`P``Z+X```<$``#LO@``!P8``/"^```'!P``]+X```<(``#X
MO@``!PD``/R^```'"@```+\```<,```$OP``!PT```B_```'#@``#+\```</
M```0OP``!Q$``!2_```'$P``&+\```<5```<OP``!Q8``""_```'%P``)+\`
M``<8```HOP``!QD``"R_```'&@``,+\```<;```TOP``!QT``#B_```''@``
M/+\```<?``!`OP``!R```$2_```'(0``2+\```<B``!,OP``!R,``%"_```'
M)0``5+\```<G``!8OP``!R@``%R_```'*@``8+\```<L``!DOP``!RT``&B_
M```'+@``;+\```<O``!POP``!S```'2_```',@``>+\```<S``!\OP``!S0`
M`("_```'-0``A+\```<V``"(OP``!S<``(R_```'.```D+\```<Y``"4OP``
M!SH``)B_```'.P``G+\```<\``"@OP``!SX``*2_```'/P``J+\```=```"L
MOP``!T$``+"_```'0P``M+\```=$``"XOP``!T4``+R_```'1@``P+\```=(
M``#$OP``!TD``,B_```'2@``4X/L".B+!@``@<-[K0``BX,0`0``A<!T!>C6
M`P``@\0(6\,`_[,$````_Z,(`````````/^C#````&@`````Z>#_____HQ``
M``!H"````.G0_____Z,4````:!````#IP/____^C&````&@8````Z;#_____
MHQP```!H(````.F@_____Z,@````:"@```#ID/____^C)````&@P````Z8#_
M____HR@```!H.````.EP_____Z,L````:$````#I8/____^C,````&A(````
MZ5#_____HS0```!H4````.E`_____Z,X````:%@```#I,/____^C/````&A@
M````Z2#_____HT````!H:````.D0_____Z-$````:'````#I`/____^C2```
M`&AX````Z?#^____HTP```!H@````.G@_O___Z-0````:(@```#IT/[___^C
M5````&B0````Z<#^____HU@```!HF````.FP_O___Z-<````:*````#IH/[_
M__^C8````&BH````Z9#^____HV0```!HL````.F`_O___Z-H````:+@```#I
M</[___^C;````&C`````Z6#^____HW````!HR````.E0_O___Z-T````:-``
M``#I0/[___^C>````&C8````Z3#^____HWP```!HX````.D@_O___Z.`````
M:.@```#I$/[___^CA````&CP````Z0#^____HX@```!H^````.GP_?___Z.,
M````:``!``#IX/W___^CD````&@(`0``Z=#]____HY0```!H$`$``.G`_?__
M_Z.8````:!@!``#IL/W___^CG````&@@`0``Z:#]____HZ````!H*`$``.F0
M_?___Z.D````:#`!``#I@/W___^CJ````&@X`0``Z7#]____HZP```!H0`$`
M`.E@_?___Z.P````:$@!``#I4/W___^CM````&A0`0``Z4#]____H[@```!H
M6`$``.DP_?___Z.\````:&`!``#I(/W___^CP````&AH`0``Z1#]____H\0`
M``!H<`$``.D`_?___Z/(````:'@!``#I\/S___^CS````&B``0``Z>#\____
MH]````!HB`$``.G0_/___Z/4````:)`!``#IP/S___^CV````&B8`0``Z;#\
M____H]P```!HH`$``.F@_/___Z/@````:*@!``#ID/S___^CY````&BP`0``
MZ8#\____H^@```!HN`$``.EP_/___Z/L````:,`!``#I8/S___^C\````&C(
M`0``Z5#\____H_0```!HT`$``.E`_/___Z/X````:-@!``#I,/S___^C$`$`
M`&:0_Z,8`0``9I"-3"0$@^3P_W'\58GE5XG/5E/H>0(``('#::D``%&#["R+
M002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=104>C*_?__BX,<`0``@\0,
M4%#_LR0!``#HE$D``(N#"`$``(/$$(`X``^$,@$``(NS!`$``(/L#/\VZ!+]
M__^`B$H"```"6O\VZ`/]__^#Q!"`B$H"```!BP>#P`4]____/P^'@@$``(/L
M#,'@`E#HS?S__XMUU(L/@\00B8-T!0``BQ:)3<S'@W@%```$````B1"-DQ.C
M__^)4`2+DSP!``")4`B-DQ:C__^)4`R#^0%^'8M]S(U6!(U($(TTOF:0BSJ#
MP@2#P02)>?PYUG7QBWW,@^P,QT2X#`````"#QP-J`%"-@[")__]74/^S@`4`
M`.C*_?__@\0@B<:%P`^$E@```(/L#/^S@`4``(U]X.B\^___B?J-@^.A___H
MWRH``(/$$(7`#X2%````@^P,_[.`!0``Z&;[___H(?W__X/$$(GPBTWD93,-
M%`````^%LP```(UE\%E;7E]=C6'\P^BK^___B8.`!0``A<`/A(H```"#[`Q0
MZ!3[__^+LP0!``!9_S;HQOO__X/$$,:`]04```#IF_[__X/L#/^S@`4``.B)
M_?__@\00B<;I4O___XN#?`4``(7`=!&#[`Q0Z&Q'``"#Q!#I8/___XGZC8.8
MH?__Z"<J``")@WP%``"%P`^$1?___^O24%"-@U.A____LQ0!``!0Z"/\__^#
M[`QJ`>B)_?__Z%1(```Q[5Z)X8/D\%!44N@B````@<,DIP``C8,0H?__4(V#
ML*#__U!15O^S(`$``.C3^?__](L<),.-@X0%``!FD&:09I!FD(L<),-FD&:0
M9I!FD&:09I#HX````('"VZ8``(V*0`$``(V"0`$``#G(=!V+@OP```"%P'03
M58GE@^P44?_0@\00R<.-="8`D,.-M"8`````Z*````"!PINF``!5B>53C8I`
M`0``C8)``0``@^P$*<C!^`*)P\'K'P'8T?AT%(N2+`$``(72=`J#[`A04?_2
M@\00BUW\R<.-M"8`````9I!5B>53Z%?___^!PT>F``"#[`2`NU`!````=2>+
M@Q@!``"%P'01@^P,_[,T`0``Z)7\__^#Q!#H-?___\:#4`$```&+7?S)PXVT
M)@````!FD.E;____BQ0DPV:09I!FD)!5C5`X5U93@>P,`P``B40D:(U$)'B-
MK"2`````98L=%````(F<)/P"```QVXE$)`B-G"0``0``B40D$(ET)!B)?"0<
MB=^-=@"+2@2+`L=%_`````"#Q1#'1?0`````@\((#\B)1>B)R,'H"(D,)"4`
M_P``QT0D!`````")PXG(P>@8"=B+'"2)V<'C",'A&`G(B=F!X0``_P`)P8E-
M\#GO=::+5"0(BT0D$('"``(``(G%B10DC78`BU5HBT5L@\4(QT5\`````#-5
M.#-%/#-5"#-%##-5^#-%_(G'B=&)T`'1#ZSX'PG!B4UX.RPD=<B+;"1HBW44
MBT4`BTT(BWT<BU4$BUT,B70D!(MU&(E,)!B)P8E\)`R+?2`/K-$;B70D"(G&
MB5PD','F!8M=$(MM)`G.B7PD4(E4)!2+?"10,=(#?"1XB6PD5(GYBVPD5!-L
M)'R)'"2!P9EY@EJ)1"00B>N)\(/3``'(BTPD&!':BQPDB40D((E4)"2+5"0(
MB=TQU8GO(<^)^HM\)`B+1"0@QT0D)`````"+;"0<BTPD#,=$)#P`````,?J+
M?"08QT0D1``````!T(GZB?Z)1"0@BP0DP>(>#ZSN`HG3BU0D"`GS`Y0D@```
M`!.,)(0```")7"0XBW0D.(E<)#")RXG1BU0D%('!F7F"6H/3`#'&BT0D$(E,
M)"B)]XMT)""+3"0HB5PD+"''QT0D+`````")^XL\)(GP,?N+?"0D`=G!X`6)
M1"0HB?V)]XMT)"@/K.\;"?Z)\(MT)`0!R(E$)"B+1"00B<$/K-`"P>$>B<L)
MPXG=B5PD0(L<)`.<)(@```"+3"0PQT0D3``````3M"2,````B=B+?"0D!9EY
M@EJ)\HMT)""#T@`QZ3';(<XS="0XB?$!P8M$)"@1TXM4)"R)3"0PB<:)7"0T
MBUPD/`^LT!O!Y@7'1"0T`````(G!"?&+="0@B<@#1"0PB?(/K/X"B40D,(M\
M)##!XAZ)\8G6"<Z+3"0X`XPDD````(G($YPDE````(ET)$@%F7F"6HG:@](`
M,?4C;"0H,VPD0(GI,=N+;"0T`<&)^!'3P>`%B4PD(`^L[QN)7"0DB<,)^XG8
M`T0D((E$)"#'1"0D`````(M,)"B+7"0LQT0D/`````")R,'@'@^LV0*+7"1$
MQT0D1`````")P@G*BTPD0`.,))@```")R!.<))P```")U8E4)#@%F7F"6HG:
MB?&+="1(@](`,>DC3"0PB40D*(E4)"R+1"0@B<HQVS'RB=$#3"0H$UPD+,'@
M!8E,)"B+5"0DB<&+1"0@B5PD+(M<)#3'1"0L``````^LT!N)1"1`"TPD0(G(
MBTPD,`-$)"B)1"0HB<@/K-D"P>`>B<()RHE4)$`#M"2@````B?"+="0XB50D
M6`69>8):,=4C;"0@BU0D+#'NBUPD),=$)#0`````B?''1"1,``````'!BT0D
M*(G&B<?!Y@4/K-<;B70D,(MT)#`)_HGP`<B+3"0@B40D,(G.P>8>B?")S@^L
MW@*+7"0\B?&)Q@G.BTPD.`.,)*@```")R!.<)*P```"+3"18B?4%F7F"6HG:
MB70D2(/2`#'QBW0D*#';(<XS="1`B?$!P8M$)#`1TXM4)#2)3"0@B<:)7"0D
MBTPD*`^LT!O!Y@7'1"0D`````(G#"?.)V`-$)""+7"0LB40D((G(P>`>#ZS9
M`HG&"<Z)="0XBTPD0`.,)+````"+5"0DB70D6(G(BUPD-,=$)"P`````!9EY
M@EHQ]8MT)$@C;"0PQT0D/``````Q]<=$)$0`````B>D!P8M$)"#!X`6)1"0H
MBT0D((ML)"@/K-`;B40D0`ML)$")Z`'(BTPD,(E$)"B)R`^LV0+!X!Z)P@G*
M`[0DN````(M,)%B)\(MT)#B)U8E4)$`%F7F"6C'1(TPD((M4)"PQSHGQ`<&+
M1"0HB<;!Y@6)="0PB<8/K-8;B70D2(MT)#`+="1(B?`!R(E$)##'1"0T````
M`(M<)""+="0DBWPD,,=$)"0`````B=J)V8M<)"S'1"1,``````^L\0+!XA['
M1"0\``````G*BTPD.`.,),````")R(E4)$@%F7F"6C'5(VPD*#-L)$")Z8ML
M)#2)5"18`<&)^,'@!0^L[QN)1"0@BW0D(`G^B?"+="1(`<B+3"0HB40D((G(
M#ZS9`L'@'HG""<J+3"1``XPDR````(G(BTPD6(G5B50D.`69>8):,=$C3"0P
MBU0D)#'.B?$!P8M$)"#!X`6)QHM$)"`/K-`;B40D*`MT)"B)\`'(B40D*,=$
M)"P`````BTPD,(M<)#2+="0XQT0D-`````")R,=$)$0`````P>`>#ZS9`HM<
M)#S'1"1,`````(G""<J+3"1(`XPDT````(G(B50D0`69>8):,=4C;"0@B50D
M6#'NBU0D+(ML)"2)\0'!BT0D*(G/B<'!X06)3"0PB=&+="0PB<(/K,H;"=:)
M\`'XBWPD((E$)#")^8G^P>$>#ZSN`HG(B?&)Q@G.BTPD.`.,)-@```")R!.<
M)-P```"+3"18B?4%F7F"6HG:B70D2(/2`#'QBW0D*#';(<XS="1`B?$!P8M$
M)#`1TXM4)#2)3"0@B<:)7"0D#ZS0&\'F!8G#"?.)V`-$)""+3"0HQT0D)```
M``"+7"0LBU0D)(E$)"")R,=$)#P`````P>`>#ZS9`HM<)#3'1"0L`````(G&
MQT0D1``````)SHM,)$`#C"3@````B<B)="0X!9EY@EJ)="18,?6+="1((VPD
M,#'UB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B40D0`ML)$")Z`'(BTPD
M,(E$)"B)R`^LV0+!X!Z)P@G*`[0DZ````(M,)%B)\(MT)#B)5"1`B=4%F7F"
M6C'1(TPD(#'.B?$!P8M$)"B+5"0LQT0D-`````"+7"0@QT0D3`````")QL=$
M)#P`````P>8%B70D,(G&#ZS6&XG:B70D2(MT)#`+="1(B?"+="0DQT0D)```
M```!R(G9P>(>BUPD+`^L\0*)1"0PBWPD,`G*BTPD.`.,)/````")R(E4)%@%
MF7F"6C'5(VPD*#-L)$")Z8ML)#2)5"1(`<&)^,'@!0^L[QN)1"0@BW0D(`G^
MB?`!R(M,)"B)1"0@B<@/K-D"P>`>B<()RHM,)$`#C"3X````B<B+3"18B50D
M.(G5!9EY@EHQT2-,)#"+="1(QT0D+`````"+5"0DBUPD-,=$)$0`````,<['
M1"0T`````(GQQT0D3``````!P8M$)"#!X`6)QHM$)"`/K-`;B40D*`MT)"B)
M\(MT)#@!R(M,)#")1"0HB<@/K-D"BUPD/,'@'HG""<J+3"1(`XPD``$``(G(
MB50D0`69>8):,=4C;"0@B50D6#'NBU0D+(ML)"2)\0'!BT0D*(G/B<'!X06)
M3"0PB=&+="0PB<(/K,H;"=:)\`'XBWPD((E$)#")^8G^P>$>#ZSN`HG(B?&)
MQ@G.BTPD.(ET)$@#C"0(`0``B?43G"0,`0``B<B+3"18!9EY@EJ)VH/2`#'Q
MBW0D*#';(<XS="1`B?$!P8M$)#`1TXM4)#2)3"0@B<:)7"0D#ZS0&\'F!8M4
M)"S'1"0D`````(G!"?&)R(M,)"`!P8M$)"@Q_XG.B4PD6(G!#ZS0`HM4)$#!
MX1Z)RPG#`Y0D$`$``(G0BU0D-(E<)$`%F7F"6C'=(VPD,#-L)$B)Z0'!B?#!
MX`6)1"0@B?"+;"0@#ZSX&XE$)"B+1"0P"VPD*`'IB4PD8(E,)"")P0^LT`*+
M5"1(P>$>B<V+3"1,"<6);"0X`Y0D&`$``(G0$XPD'`$``(ML)$`%H>O9;HG*
MBUPD.(/2`(E$)"B+1"0@B50D+(M4)%@QZS':,=N)T0-,)"B+5"0DB4PD*(G!
M$UPD+,'A!8E<)"R)3"0PB=&)P@^LRAN+3"0PQT0D+`````")5"1`"TPD0(GR
MB<B+3"0H`<$/K/X"P>(>B?")3"0HB=:+E"0@`0``B4PD2(N,)"0!```)QH'"
MH>O9;HET)$"#T0")T#';B<H!Z(ML)&"+3"0L$=J+7"0X,?\Q\S'=B<N)[@'&
M$=>+5"0HB70D,(E\)#2)UXG1P><%#ZS9&XG]"<V+3"0P`>F)3"18BW0D((M\
M)"2+7"1(B4PD,(GQQT0D-`````"+E"0P`0``P>$>#ZS^`HM\)"S'1"0D````
M`(G-BTPD.`GUB[0D*`$``(EL)#B!QJ'KV6Z)\`'(BTPD0#'I,<N+3"0PB=Z+
M7"0T`<:)R,'@!0^LV1N)1"0@BVPD((M$)$`)S0'NB70D((ET)$B+="0HB?$/
MK/X"BWPD6,'A'HG+BXPD-`$```GS@<*AZ]ENBW0D.(/1`(G=B<N)T3'2`<@1
MVC'N,=LQ]XGY`<&+1"0@$=.+5"0DB4PD*(G&B5PD+(M,)"@/K-`;P>8%QT0D
M+`````")PXM$)#`)\P'9B4PD0(E,)"B+5"0TB<'!X1Z+="1(QT0D-``````/
MK-`"BU0D+`G!BT0D.(G/BXPD.`$``(E\)%B!P:'KV6X!R(GY,>DQSHGQ`<&+
M1"0HP>`%B40D,(M$)"B+="0P#ZS0&XM4)"3'1"0D`````(E$)#B+1"0@"W0D
M.`'QB4PD,(E,)$B)P0^LT`*+5"0TP>$>B<Z+C"1``0``"<:)Z(G]@<&AZ]EN
MB70D.`'(,?6+="1`,>Z)\0'!BT0D,(G.B<'!X06)3"0@B=&)PHM<)"`/K,H;
MBT0D*(GQB50D0`M<)$`!V8M4)"R)QHE,)$")3"0@B<$/K-8"P>$>B<L)\XNT
M)$@!``"+O"1,`0``BT0D6(G=@<:AZ]EN@]<`,=(!\(MT)#@1^HM\)$@QVS'N
M,?>)^0'!BT0D(!'3BU0D)(E,)"B)QHE<)"P/K-`;P>8%BU0D-,=$)"P`````
MB<''1"0T``````GQBW0D0(G(BTPD*`'!BT0D,(E,)"B)3"1(B<$/K-`"BY0D
M4`$``,'A'HG+"<.+1"0X@<*AZ]ENB=\!T#'KBU0D+(E\)%@QWHGQ`<&+1"0H
MP>`%B40D,(M$)"B+="0P#ZS0&XM4)"2)1"0XBT0D(`MT)#@!\8E,)$")3"0P
MB<$/K-`"BY0D6`$``,'A'HG."<:!PJ'KV6Z)Z(G]`=")="0X,?6+="1(BU0D
M-(N\)&0!``#'1"0D`````#'NB?$!P8M$)#")SHG!P>$%B4PD((G1B<(/K,H;
MBTPD((E4)$@+3"1(B<B)\8M4)"P!P8M$)"B)3"1(B4PD((G!B<:+1"18P>$>
M#ZS6`HG-"?6+M"1@`0``@<:AZ]EN@]<`,=(!\(MT)#@1^HM\)$`QVS'N,?>)
M^0'!BT0D(!'3BU0D)(E,)"B)QHE<)"P/K-`;P>8%BU0D-,=$)"P`````B<$)
M\8MT)$B)R(M,)"@!P8M$)#")3"0HB4PD0(G!#ZS0`HN4)&@!``#!X1Z)RPG#
MBT0D.('"H>O9;HG?`=`QZS'>B?$!P8M$)"C!X`6)1"0PBT0D*(M4)"R+="0P
MQT0D-`````")?"18#ZS0&XM4)"3'1"0D`````(E$)#B+1"0@"W0D.`'QB4PD
M2(E,)#")P0^LT`*+E"1P`0``P>$>B<X)QH'"H>O9;HGHB?T!T(ET)#@Q]8MT
M)$"+5"0TB[PD?`$``#'NB?$!P8M$)#")SHG!P>$%B4PD((G1B<(/K,H;BTPD
M((E4)$`+3"1`B<B)\8M4)"P!P8M$)"B)3"1`B4PD((G!B<:+1"18P>$>#ZS6
M`HG-"?6+M"1X`0``@<:AZ]EN@]<`,=(!\(MT)#@1^HM\)$@QVS'N,?>)^0'!
M$=.)3"0HB5PD+(M$)""+5"0DQT0D+`````")Q@^LT!O!Y@6+5"0TQT0D-```
M``")P0GQBW0D0(G(BTPD*`'!BT0D,(E,)$B)3"0HB<$/K-`"BY0D@`$``,'A
M'HG+"<.+1"0X@<*AZ]ENB=\!T#'KBU0D+(E\)%@QWHGQ`<&+1"0HP>`%B40D
M,(M$)"B+="0P#ZS0&XM4)"2)1"0XBT0D(`MT)#@!\8E,)#")3"1`B<$/K-`"
MBY0DB`$``,'A'HG."<:!PJ'KV6Z)Z(G]`=")="0X,?6+="1(BU0D-#'NB?$!
MP8M$)#")SHG!P>$%B4PD((G1B<(/K,H;BTPD((E4)$@+3"1(B<B)\8M4)"R+
MO"24`0```<&+1"0HQT0D)`````")3"1(B4PD((G!B<:+1"18P>$>#ZS6`HG-
M"?6+M"20`0``@<:AZ]EN@]<`,=(!\(MT)#@1^HM\)$`QVS'N,?>)^0'!BT0D
M(!'3BU0D)(E,)"B)QHE<)"P/K-`;P>8%BU0D-,=$)"P`````B<$)\8MT)$B)
MR(M,)"@!P8M$)#")3"0HB4PD6(G!#ZS0`HN4))@!``#!X1Z)RPG#BT0D.('"
MH>O9;HG?`=`QZXM4)"PQWHGQ`<&+1"0HP>`%B40D,(M$)"B+="0P#ZS0&XE$
M)#@+="0X`?&)3"1(B4PD,(M$)""+5"0DQT0D-`````")P8E\)&P/K-`"P>$>
MBY0DH`$``,=$)#P`````B<X)QH'"H>O9;HGHB?T!T(ET)$`Q]8MT)%B+5"0T
MBWPD*#'NBVPD+(GQ`<&+1"0PB<Z)P<'A!8E,)"")T8G"#ZS*&XM,)"")5"0X
M"TPD.(GZB<B)\8G^`<'!XAX/K.X"B=6+E"2H`0``B4PD.(E,)&"+C"2L`0``
M"?6!PJ'KV6Z);"18@]$`B=`QVXG*BTPD;`'(BTPD0!':BUPD2#'_,>DQRXG9
MB?L!P1'3BU0D.(E,)""+3"0\B5PD)(G7QT0D)`````#!YP6)RXG1#ZS9&XG^
M"<Z)\`-$)"")1"0@BW0D,(M\)#3'1"1,`````(GQQT0D-`````#!X1X/K/X"
MB<N+C"2P`0``"?.)W8'!H>O9;HE<)$B+G"2T`0``B<B+3"1`@],`B=HQVP'(
MBTPD6!':BUPD8#'_,>DQRXG9B?N+?"0\QT0D/``````!P8E,)"B+3"0@$=.)
M7"0LBUPD)(G(B<K'1"0L`````,'@!0^LVAN)Q@G6BU0D+(GPBW0D.`-$)"B)
M1"0HB?$/K/X"P>$>B?")SHN,)+@!```)QHM$)%B!P=R\&X^)]XET)#@!R(ET
M)%@)]8MT)$@C;"0@(?X)]8GI`<&+1"0HB<:)Q\'F!0^LUQN)="0PBW0D,`G^
MB?`!R(E$)#"+3"0@BUPD)(M\)$S'1"1$`````(G(QT0D3`````#!X!X/K-D"
M,=N)PHM$)"@)RHM,)%B)U8E4)$`)T8M4)#@AR"'JB<8)UHGQBW0D2`.T),`!
M``")\!.\),0!``")^@7<O!N/@](``<&+1"0P$=.+5"0TB4PD((G&B5PD)(M<
M)"P/K-`;P>8%B<$)\8G(BTPD*`-$)"`Q_XG&B<@/K-D"P>`>B<*+1"0X"<J)
MT0G5B50D2"-L)#")5"18BU0D0"'*"=4#A"3(`0``B>D%W+P;CP'!B?#!X`6)
M1"0@B?"+;"0@#ZSX&XE$)"@+;"0HB>@!R(E$)""+3"0PBUPD-(M4)$C'1"0D
M`````(G(QT0D/`````#!X!X/K-D",=N)Q0G-BTPD6"'JB6PD.`GIB<@A\`G0
MBU0D1,=$)$0`````B<&+1"1``X0DT`$``!.4)-0!```%W+P;CX/2``'!BT0D
M(!'3B4PD*(M4)"2)P8E<)"S!X07'1"0L`````(E,)#")T8G"#ZS*&XM,)#")
M5"1`"TPD0(G(B?$#1"0HP>$>B40D*(G(B?&+="1(#ZSY`HG""<J)T0G5B50D
M0"-L)"")5"18BU0D."'*"=4#M"38`0``BWPD*,=$)#0`````B?")Z8ML)"R+
M7"0D!=R\&X^+5"1`QT0D3``````!P8GX#ZSO&\=$)"0`````P>`%QT0D/```
M``")1"0PBW0D,`G^B?"+="0X`<B+3"0@B40D,(G(#ZS9`HM<)"S!X!Z)Q8M$
M)"@)S8M,)%@AZHEL)$@)Z2'("=`#M"3@`0``BU0D-(G!B?`%W+P;CP'!BT0D
M,(G&#ZS0&XE$)"#!Y@4+="0@B?"+="1``<B+3"0HB40D((G(#ZS9`L'@'HG"
M"<J)T0G5B50D."-L)#")5"18BU0D2"'*"=4#M"3H`0``B?")Z07<O!N/`<&+
M1"0@BU0D),=$)"P`````BVPD-,=$)#0`````B<:)Q\'F!0^LUQN+5"0XB70D
M*(MT)"@)_HM\)#")\`'(B?DQV\'A'HE$)"B)R(GYBWPD3`^LZ0*)Q8M$)"`)
MS8M,)%@AZHEL)#`)Z2'(B<8)UHGQBW0D2`.T)/`!``")\!.\)/0!``")^@7<
MO!N/@](``<&+1"0H$=.+5"0LB4PD0(G&B5PD1(M<)"0/K-`;P>8%QT0D1```
M``")P0GQB<B+3"0@`T0D0#'_B<:)R`^LV0+!X!Z)PHM$)#@)RHG1"=6)5"1`
M(VPD*(E4)$B+5"0P(<H)U0.$)/@!``"+7"0LQT0D)`````")Z07<O!N/BU0D
M0,=$)#P``````<&)\,'@!8E$)"")\(ML)"`/K/@;B40D.`ML)#B)Z`'(BTPD
M*(E$)"")R`^LV0(QV\'@'HG%"<V+3"1((>J);"0X">F)R"'P"="+5"0TB<&+
M1"0P`X0D``(``!.4)`0"```%W+P;CX/2``'!BT0D(!'3B4PD*(M4)"2)P8E<
M)"S!X07'1"0L`````(E,)#")T8G"#ZS*&XM,)#")5"1("TPD2(G(B?$#1"0H
MP>$>B40D*(G(B?$/K/D"B<()RHG1"=6)5"1(QT0D3``````C;"0@BW0D0(M\
M)"B)5"18BU0D.(M<)"3'1"0T`````,=$)$0`````(<K'1"0D``````G5`[0D
M"`(``(M4)$C'1"0\`````(GPB>F+;"0L!=R\&X\!P8GX#ZSO&\'@!8E$)#"+
M="0P"?Z)\(MT)#@!R(M,)"")1"0PB<@/K-D"BUPD+,'@'HG%BT0D*`G-BTPD
M6"'JB6PD0`GI(<@)T`.T)!`"``"+5"0TB<&)\`7<O!N/`<&+1"0PB<8/K-`;
MB40D(,'F!0MT)"")\`'(BTPD*(E$)"")R`^LV0+!X!Z)P@G*B=$)U8E4)#B)
M5"18BU0D0"-L)#"+="1(QT0D+``````AR@G5`[0D&`(``(M4)"2)\(GIBVPD
M-,=$)#0`````!=R\&X\!P8M$)"")QHG'P>8%#ZS7&XM4)#B)="0HBW0D*`G^
MBWPD,(GP`<B)^3';P>$>B40D*(G(B?F+?"1$#ZSI`HG%BT0D(`G-BTPD6"'J
MB6PD,`GI(<B)Q@G6B?&+="1``[0D(`(``(GP$[PD)`(``(GZ!=R\&X^#T@`!
MP8M$)"@1TXM4)"R)3"1`B<:)7"1$BUPD)`^LT!O!Y@6)P0GQB<B+3"0@`T0D
M0#'_B<:)R`^LV0+!X!Z)P@G*B=$)U8E4)$#'1"1$`````"-L)"B+1"0XBUPD
M+(E4)$B+5"0PQT0D)`````#'1"0\`````"'*"=4#A"0H`@``BU0D0(GI!=R\
M&X\!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0X"VPD.(GH`<B+3"0HB40D((G(
M#ZS9`C';P>`>B<4)S8M,)$@AZHEL)#@)Z8G((?`)T(M4)#2)P8M$)#`#A"0P
M`@``$Y0D-`(```7<O!N/@](``<&+1"0@$=.)3"0HBU0D)(G!B5PD+,'A!8E,
M)#")T8G"#ZS*&XM,)#")5"1("TPD2(G(B?$#1"0HBU0D.,'A'HE$)"B+7"0D
MB<B)\<=$)"P`````#ZSY`HG&BWPD*,=$)#0`````"<['1"1$`````"'R"?4C
M;"0@B70D,(G0B>J)="1(BW0D0`G"`[0D.`(``(ML)"R)\(G1!=R\&X\!P8GX
M#ZSO&\'@!8E$)$"+="1`"?Z)\`'(BTPD(#'_B<:)R`^LV0(QV\'@'HG"BT0D
M*`G*BTPD2(G5B50D0`G1BU0D,"'((>H)T(M4)#R)P8M$)#@#A"1``@``$Y0D
M1`(```7<O!N/@](``<&)\!'3P>`%B4PD((G!B?")7"0D#ZSX&XE$)#@+3"0X
MB<@#1"0@BTPD*,=$)"0`````B40D((M<)"R)R,=$)"P`````P>`>#ZS9`C';
MQT0D/`````")PHM$)#`)RHG1B50D*`G5B50D8(M4)$`A]2'*"=4#A"1(`@``
MBU0D-(GI$Y0D3`(```7<O!N/@](``<&+1"0@$=.)3"0PBU0D)(G!B5PD-,'A
M!<=$)#0`````B4PD.(G1B<*+7"0X#ZS*&XM,)#"+1"0@B50D2`M<)$@!V8M4
M)"@QVXE,)%B)3"0PB?$/K/X"P>$>B<V+3"1@"?4)Z2'JB6PD."'(B<8)UHGQ
MBW0D0(M\)$0#M"10`@``$[PD5`(``(GPB?H%W+P;CX/2``'!BT0D,!'3BU0D
M-(E,)$")QHE<)$2+?"1$#ZS0&\'F!3'2B<.+1"0@"?.+="1`B<$!WA'7BU0D
M),'A'HET)&")RXE\)&2+3"0H,?\/K-`""<,#C"18`@``B5PD2(G(BUPD+!.<
M)%P"```%UL%BRHG:B40D((GP@](`,VPD2(E4)"2+5"18,>J)T0-,)"#!X`6)
M1"0@B?"+;"0@#ZSX&XE$)"@+;"0H`>F)3"18B4PD(,=$)"0`````BT0D,(M4
M)#2+7"0\B<'!X1X/K-`"B<V+3"0X"<4#C"1@`@``$YPD9`(``(G(B=J);"1`
MBVPD2`76P6+*BTPD0(/2`(E$)"B+1"0@,=N)5"0LBU0D8#'I,<J)T0-,)"B+
M5"0DB4PD*(G!$UPD+,'A!8E<)"R)3"0PB=&)P@^LRAO!Z1O'1"0L`````(E4
M)#B)\HE,)#R+3"0P"TPD.(G(BTPD*`'!#ZS^`L'B'HGPB4PD2(G6BY0D:`(`
M`(E,)"B+C"1L`@``"<:!PM;!8LJ)="0X@]$`B=`QVXG*`>B+3"1`$=J+7"18
M,?\Q\3'+BTPD+(G>`<:)RQ'7BU0D*(ET)#")?"0TB=>)T<=$)#0`````BU0D
M+,'G!0^LV1N+7"1(B?Z+?"0DQT0D)``````)SHGPBW0D,`'&B70D6(ET)#"+
M="0@B?$/K/X"P>$>"?&)SHN,)'`"``"!P=;!8LJ)R(M,)$")="1``<B+3"0X
M,?$QRXM,)#")WHM<)#0!QHG(P>`%#ZS9&XM<)$")1"0@BT0D*(ML)"`)S8G!
M`>[!X1X/K-`"B<V+E"1X`@``B70D(`G%BT0D.('"UL%BRHEL)#@!T#'KBVPD
M6#'=B>D!P8M$)"#!X`6)1"0HBT0D((M4)"2+;"0HQT0D+``````/K-`;BU0D
M-,=$)#0`````B40D2(M$)#`+;"1(`>F)3"1(B4PD*(G!#ZS0`HM4)"S!X1X)
MP8M$)$")S8N,)(`"``");"1`@<'6P6+*`<B+3"0X,>F)S3'UB>D!P8M$)"B)
MQHG'BT0D(,'F!0^LUQN+5"0DB70D,(MT)#`)_HM\)#0!\8G&B4PD,`^LU@*)
M3"18B<&)\,'A'HG.BXPDB`(```G&BT0D.(GUBW0D0('!UL%BR@'(B6PD.#'N
MBVPD2#'UBW0D,(GIB?T!P8GPB??!X`4/K.\;B40D((MT)"`)_@'QB4PD((M$
M)"B)SHM4)"R+;"18QT0D)`````")P<=$)"P`````P>$>#ZS0`HM4)"2)RXN,
M))`"```)PXM$)$"!P=;!8LJ)7"1``<B+3"0X,=DQS8GI`<&+1"0@P>`%B40D
M*(M$)""+;"0H#ZS0&XM4)#3'1"0T`````(E$)$B+1"0P"VPD2`'IB4PD*(E,
M)$B)P0^LT`*+5"0LP>$>B<V+C"28`@``"<6+1"0X@<'6P6+*B6PD.`'(BTPD
M0#'IB<TQ]8GI`<&+1"0HB<:)QXM$)"#!Y@4/K-<;B70D,(MT)#`)_@'QB<;!
MYAZ)3"18B4PD,(M4)"2)\8G&BWPD-,=$)"0`````#ZS6`HM4)"S'1"0L````
M`(GPB<X)QHM$)$")]8NT)*`"``");"1`@<;6P6+*`?"+="0X,>Z+;"1(,?6+
M="0PB>F)_0'!B?")]\'@!0^L[QN)1"0@BW0D((M$)"@)_@'QB4PD((G.B<$/
MK-`"P>$>BU0D)`G!BT0D.(G-BXPDJ`(``(EL)#B!P=;!8LH!R(M,)$`QZ8ML
M)%@QS8GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XM4)#2)1"1(BT0D,`ML
M)$@!Z8E,)$B)3"0HB<$/K-`"P>$>B<V+C"2P`@``"<6+1"1`BU0D+,=$)#0`
M````@<'6P6+*B6PD0`'(BTPD.#'IB<TQ]8GI`<&+1"0HB<:)QXM$)"#!Y@4/
MK-<;BU0D),=$)"0`````B70D,(MT)#`)_HM\)#0!\8G&P>8>B4PD6(E,)#")
M\8G&#ZS6`HM4)"R)\(G."<:+1"0XB?6+M"2X`@``B6PD.('&UL%BR@'PBW0D
M0#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`4/K.\;B40D((MT)""+1"0H"?X!
M\8G.B4PD((G!#ZS0`L'A'@G!BT0D0(G-BXPDP`(``(EL)$"!P=;!8LH!R(M,
M)#@QZ8ML)%@QS8GI`<&+1"0@P>`%B40D*(M$)""+5"0DBVPD*,=$)"P`````
M#ZS0&XM4)#3'1"0T`````(E$)$B+1"0P"VPD2`'IB4PD2(E,)"B)P0^LT`*+
M5"0LP>$>B<V+C"3(`@``"<6+1"0X@<'6P6+*B6PD.`'(BTPD0#'IB<TQ]8GI
M`<&+1"0HB<:)QXM$)"#!Y@4/K-<;BU0D)(ET)#"+="0P"?Z+?"0T`?&)QL'F
M'HE,)#")3"18B?&)Q@^LU@*)\(G."<:+1"1`B?6+M"30`@``B6PD0('&UL%B
MR@'PBW0D.#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`4/K.\;B40D((MT)"`)
M_@'QB4PD((M$)"B)SHM4)"R+G"3<`@``QT0D)`````")P<=$)"P`````#ZS0
M`L'A'@G!BT0D.(G-BXPDV`(``(EL)#B!P=;!8LJ#TP`QT@'(BTPD0!':,=LQ
MZ8ML)%@QS8GI`<&+1"0@$=.+5"0DP>`%B40D*(M$)""+;"0H#ZS0&S'2B40D
M2(M$)#`+;"1(`>D1TXE,)"B+5"0TB4PD2(G!P>$>#ZS0`HE<)$R+G"3D`@``
MB<V+C"3@`@``"<6+1"1`@<'6P6+*B6PD0(/3`#'2`<B+3"0X$=HQVS'IB<TQ
M]8GI`<&+1"0H$=.+5"0LB<:)Q\'F!0^LUQLQTHET)#"+="0P"?X!\1'3B4PD
M6(E<)%R+1"0@BU0D)(E,)#")QL=$)#0`````BWPD-,'F'L=$)"0`````B?&)
MQ@^LU@*+5"0LB?")S@G&BT0D.(GUB[0DZ`(``(EL)#B!QM;!8LH!\(MT)$`Q
M[HML)$@Q]8MT)#")Z8G]`<&)\(GWP>`%#ZSO&XE$)""+="0@"?Z)\`'(B40D
M((M$)"B)P0^LT`*+5"0PP>$>"<&)UHM$)$")S8M,)#3!YAZ)="0HBW0D6(G/
M#Z37'@^LR@+!Z0*)5"0PBU0D)(E,)#2+C"3P`@``B7PD+('!UL%BR@'(BTPD
M.#'I,<Z)\0'!BT0D((G&#ZS0&XE$)$#!Y@4+="1`P>H;B?")5"1$`<B)P0-,
M)!"+1"1HBW0D*(D(B<''0`0`````BT0D&`-$)"`+="0PQT$,`````(E!"(GP
M`P0DB4$0B>@#1"0(B4$8BT0D.`-$)%#'010`````QT$<`````(E!(,=!)```
M``"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</H:AX``(VT)@````"-=@!5
M5U93Z$?6__^!PS=]``"#[!R%P`^$G@```(N+#`$``(L)B4PD"(7)#X2*````
M#[8(A,ET!8#Y/75&,?:+?"0(BR^%[70OB50D#(E$)`1FD(/L!%;_="0,5>C"
MT/__@\00A<!U!X!\-0`]="R#QP2++X7M==N#Q!R)Z%M>7UW#D(G&@\8!#[8.
MA,ET!8#Y/77Q*<;KIXUV`(M$)`R)^BM4)`B-;#4!P?H"B1"#Q!R)Z%M>7UW#
MC78`@\0<,>U;B>A>7UW#C;0F`````(UT)@"0Z'#6__^!PFM\``!75HG&4X/L
M$&6A%````(E$)`PQP(NZ#`$``(U<)`B)VHGPZ/[^__^%P'0SBU0D"(L'C020
MBU`$B1"%TG3AC;0F`````)"#P`2+4`2)$(72=?2)VHGPZ,O^__^%P'7-BT0D
M#&4S!10```!U!X/$$%M>7\/H#AT``(VT)@````"-M"8`````58G%5U:)UE/H
MX]3__X'#TWL``(/L.&6A%````(E$)"@QP#'`@#H]#Y3``<96Z&[.__^#Q!")
M1"0$C50D&(GHZ%S^__^%P`^$!`$``(/L#(G'4.A)SO__@\00.T0D!`^#U```
M`(M$)!B-%(4`````BX,,`0``B00D#[9%`(3`#X2<`0``/#T/A)0!``")Z&:0
M@\`!#[8(A,ET!8#Y/77Q*>B+#"2#[`R+.0'7BU0D$(U$$`)0Z&?1__^#Q!")
M!X7`#X1M`0``BPPDBU0D&(L!C4T!BQ20#[9%`(@"/#UT'83`=0GK%XUV`#P]
M=!"#P0$/MD'_@\(!B`*$P'7LQ@(],<"-M"8`````#[8,!HA,`@&#P`&$R77Q
M,<"+7"0<93,=%`````^%$P$``(/$+%M>7UW#C;8`````,<"-M@`````/MA0&
MB!0'@\`!A-)U\NO'BX,,`0``BPB)!"2+.87_#X3"````,<#K"8VT)@````")
M^(UX`8L4N872=?2-!(4,````BY-P!0``A=)U:XE,)`B#[`Q0QX-P!0```0``
M`.A\T/__@\00A<`/A(0```"#[`2-%+T`````4HM,)!")5"0448E$)!10Z$//
M__^+5"00BT0D&(/$$(D"BU0D#(M$)`C'1+@$`````(E\)!CIA?[__XUT)@"0
M@^P(4%'HKL___XM4)!")1"08@\00B0*%P'0@C12]`````.O"C70F`#'`Z7K^
M__^X"````#'_Z5#___^X_____^G<_O__Z+X:``"-M"8`````C;0F`````%57
M5HG&4^B5TO__@<.%>0``@>R,````9:$4````B40D?#'`A?9T!8`^`'4DBT0D
M?&4S!10````/A3P!``"!Q(P```!;7E]=PXVT)@````"0@^P,5NBWS?__@\00
MB<>%P'3*C8-0H?__B00DC40D&(E$)`2#[`Q7Z+3,__^#Q!")Q87`#X2W````
M#[9%"(/X+@^$B@```(/L#%;HL<O__XU5"(D4)(E4)!B)1"0<Z)[+__^+3"0<
MC40!`HD$).@.S___B<586HM4)!!25O]T)!!J_VH!5>@6S___@\0<_W0D"%5J
M`^C'S/__@\00@_C_=`\/MT0D)&8E`/!F/0!`='"#[`Q5Z$?.__^#Q!"#[`Q5
MZ+O-__^#Q!#I5O___XUV``^V50F%T@^$1____SG0=#"#ZBZ%T@^$./___^E6
M____@^P,5^BGS/__B30DZ-_-__^#Q!#IT_[__XVT)@`````/ME4*Z\V-M"8`
M````C78`B>CHB?[__^N3Z#(9``!FD%:)QE/H%]'__X'#!W@``(/L>&6A%```
M`(E$)'`QP(U$)`Q05FH#Z!7,__^#Q!"%P'4V#[=4)!2!X@#P``"!^@!```!T
M"('Z`*```'4=@^P(:@)6Z/C*__^#Q!"%P`^4P`^VP.L%C78`,<"+3"1L93,-
M%````'4&@\1T6U[#Z*X8``"-M"8`````C;0F`````%57B<=64^B%T/__@<-U
M=P``@>PP!```B50D#&6A%````(F$)"`$```QP&C_`P``C8-6H?__C70D)%90
MZ%#-__^#Q!"%P'YQC6C_BY,$`0``@'PL'`"+$G57A>UT8XE4)`R#[`15:B]6
MZ#/*__^#Q!"+5"0,A<!T2(/L#%+H#\O__U565U#HULS__X/$((N$)!P$``!E
M,P44````=3^!Q"P$``!;7E]=PXVT)@````"0B<7KJ8UT)@"+@P0!``"+$(/L
M#%+HQ\K__X/$#/]T)`Q74.A9RO__@\00Z['HOQ<``(VT)@````"-M"8`````
MD%/HFL___X'#BG8``(/L%(N#!`$``/\PZ(3*__^-DT"C__]2C9-EH?___[,`
M`0``4E#H6LO__X/$*%O#C70F`)!64^A9S___@<-)=@``@^P0B[,$`0``_S;H
M0\K__XD$).B;____6/\VZ#/*__]:C9/PHO__66H`4E*-DW"<__]2C9.!H?__
M4E#HD\O__X/$)%M>PXVT)@````"-M@`````QP,.-M"8`````C;8`````55=6
M4^CGSO__@</7=0``@>R,!```B[PDH`0``(U4)!2+M"2D!```B7PD!&6A%```
M`(F$)'P$```QP(V#F*'__^A;^/__@^P(:B^)Q5?H/LC__X/$$(7`=#>+?"0$
MC8.AH?__B?KHEOG__XGXBXPD?`0``&4S#10````/A8`!``"!Q(P$``!;7E]=
MPXUT)@"0@^P,_W0D$.@$R/__6EF)1"00C8.NH?__B40D"%!6Z)W(__^#Q!")
MQHV#EJ'__XE$)`R-M@````"%]G2-@#X`#X3#````A>UT%8/L"%95Z*W)__^#
MQ!"%P`^$BP```(/L#%;HJ<?__X/$$(!\!O\O=16-M"8`````@^@!@'P&_R_&
M!`8`=/*+5"0(C400`3W_`P``#X\P____@^P$C8.PH?___W0D"%"-@ZNB__]6
M4&@`!```:@&-M"28````5NCMRO__@\0<C40D'%!6:@/HG<C__X/$$(7`=0\/
MMT0D)&8E`/!F/0"`=%>#[`C_="0(:@#HR<?__X/$$(G&Z3?___^-M"8`````
MA>UT'(M\)`RY`@```(GN\Z8/E\`<`(3`=,>-M@````"+="0,N`$```#I4/__
M_XVT)@````"-=@"#[`AJ`5;H1<?__X/$$(7`=9>)\HV#H:'__^@1^/__@^P,
M5NCXQO__@\00Z6S^___H^Q0``(VT)@````"-="8`BU0D!`^V"HG0A,ET&XUV
M`(/"`8#Y+P^V"@]$PH3)=?##C;0F`````,.-M"8`````5E/HJ<S__X'#F7,`
M`(/L!(MT)!"%]@^$I````(`^``^$FP```(/L#%;H,L;__X/$$(U$!O\YQG(.
MZR&-="8`D(/H`3G&=!F`."]T].L'9I"`."]T,(/H`3G&<O0YQG4E@#@O=%N#
M[`R-@["A__]0Z#S&__^#Q!"#Q`1;7L.-=@"`."]U!X/H`3G&<O0I\(U0`H'Z
M``0``'='@\`!:``$``!05HVS<`$``%;H8<C__X/$$(GP@\0$6U[#C;8`````
M@^P,:@+H%LG__X/$$(7`=`^Z+@```&:)$(/$!%M>PY"#Q`0QP%M>PXVT)@``
M``"05U93Z+C+__^!PZAR``"#[#!EH10```")1"0L,<"-="0$BX,<H___B40D
M"HN#(*/__XE$)`Z+@R2C__^)1"02BX,HH___B40D%HN#+*/__XE$)!J+@S"C
M__^)1"0>BX,TH___B40D(HN#.*/__XE$)"8/MX,\H___9HE$)"J-@[*A___H
MN/7__XV#NZ'__^BM]?__C8/#H?__Z*+U__^-@\RA___HE_7__XV#TZ'__^B,
M]?__C8/CH?__Z('U__^-@YBA___H=O7__XV#[Z'__^AK]?__C8/YH?__Z&#U
M__^-@P.B___H5?7__XV#H:'__^A*]?__B?*-@PVB___H;?3__X7`=`V)PHV#
M^:'__^B\]?__B?*-@QZB___H3_3__X7`=`V)PHV#,*+__^B>]?__B?*-@SNB
M___H,?3__X7`=#6)PHV#F*'__^B`]?__C9-GHO__C8/3H?__Z&_U__^+1"0L
M93,%%````'5=@\0P6UY?PXUV`(GRC8-+HO__Z.OS__^%P'07B<*-@^^A___H
M.O7__^NXC;0F`````)"-="0;N0H```"-NURB___SI@^7P!P`A,!UEHU4)"6-
M@^^A___H!_7__^N%Z``2``!3Z.K)__^!P]IP``"#[!AEH10```")1"0,,<"+
M@S@!``"#^/]T&HM,)`QE,PT4````=3Z#Q!A;PXVT)@````"0C50D"(V#[Z'_
M_^A1\___B<(QP(72=!(/MA*`^C`/E<$QP(32#Y7`(<B)@S@!``#KM>B*$0``
MC;0F`````(UV`%/H:LG__X'#6G```(/L".A<Q?__@^P,4.@#Q?__@\00A<!T
M#(L`@\0(6\.-="8`D(/$"#'`6\.-M"8`````9I!55U93Z"?)__^!PQ=P``"#
M[!QEH10```")1"0,,<"-5"0(BWPD,(V#::+__^BO\O__A<!T!X`X`(G&=22)
M^HV#::+__^CW\___BT0D#&4S!10```!U:X/$'%M>7UW#9I"#[`A74.A6Q/__
M@\00A<!UV(/L#%?H9L+__XDT)(G%Z%S"__^-1`4"B00DZ-#%__^#Q`R)Q8V#
MKJ'__U90C8.KHO__5U!J_VH!5>C1Q?__@\0@B>J-@VFB___H@?/__^N(Z'H0
M``"-M"8`````C78`Z%#)__^!PDMO``!55U93@>P\@0``B=&+A"10@0``B50D
M"(UT)#R-F7FB__^)1"049:$4````B80D+($``#'`C8*%HO__QT0D2`````")
M1"1`C8*6H?__C9(PHO__B40D1(V!*:+__XE$)%R-@8JB__^)1"1@C8%&HO__
MB40D9(V!DJ+__XE$)&B-@9:B__^)5"0,B50D6(GRB40D4(V!F*'__\=$)&P`
M````B5PD3,=$)%0`````Z%3Q__^%P'0)@#@`#X6?!```Z"+^__^)Q87`#X0H
M!```@^P,58M\)!B)^^@IP?__C40``8D$).B=Q/__B40D((/$$(!]``!T2HM$
M)`B+?"00B70D((V`GZ+__XG^B<>-M"8`````C78`#[9%`(/L#(/%`5!7:O]J
M`5:+7"0H@\8"Z'/$__^#Q""`?0``==J+="0@C5PD6(M$)`SK#8UT)@"#PP2+
M`X7`=#>)\NBH\/__B<>%P'3J@#@`=.7HR/7__X7`=-R#[`Q7BUPD&.C7P/__
M@\00B<>%P'5(C;8`````,>V-M@````"+7*Q`A=MT,(`[`'0KB=B#Q0'HB?7_
M_X7`=.6#[`Q3BUPD&.B8P/__@\00A<!TT8G'ZP>-="8`D#'_@^P,5XM<)!CH
M*<#__X/$$(M,)!"+&8/!!(V3__[^_O?3(=J!XH"`@(!TZ8G3P>L0]\*`@```
M#T33C5D"#T3+B=,`TX/9`RM,)!"#[`R-A`$$!```B40D+%"+;"08B>OH4L/_
M_XE$)!R)P8V%I*+___]T)"!0C86PH?__B40D*%"-A:FB__^)S5=0:O]J`5'H
M0L/__X/$*&C``0``5>C4O___@\00@_C_=1#HM[___XL`@_@1#X6R`@``@^P$
MC40D=(E$)"Q0_W0D%&H#BUPD&.C1P/__@\00B<6%P'18@^P,_W0D&(M$)"3_
M,(M<)!R-@XBC__]0BX,H`0``:@'_,.BAPO__@\0@QT0D(`````"+C"0L@0``
M93,-%````(M$)"`/A;`(``"!Q#R!``!;7E]=PXUV``^W1"1\9B4`\&8]`$!U
MF8M<)`B+O"2$````Z#'!__\YQW6%#[=$)'QF)?\!9CW``0^%<O___X/L#/]T
M)"R+?"08B?OH.,+__XGRB40D,(V'=*+__^BG[O__@\00A<`/A$0"``"#[`Q0
MBUPD&.C?OO__6EE0BT0D(/\PZ.'U__^)1"0H@\00A<`/A!H"``"#[`R+?"0D
M5XM<)!CH8;[__X/$$(/X`W8YBU0D"(UT!_R)^[D%````C;JRHO__\Z8/E\*`
MV@"$TG48@_@$#X1Z!@``@'P#^R\/A&\&``"-="8`Z'OZ__^%P'4A@^P(:@#_
M="0DBUPD&.@EOO__B40D-(/$$(7`#X6M`0``BWPD"(V79Z+__XG[C8?OH?__
MZ#_O__^-M_"B___H%,'__U90C8?+HO__C;_9HO___W0D&/]T)!A0:O]J`?]T
M)#SH4,'__X/$((ET)!2+="0@ZT"-=@"+7"0(Z,>]__^#.!%U28M<)`B#Q0'H
MQL#__X/L#/]T)"!54/]T)"C_="0H5VK_:@%6BUPD..@&P?__@\0P@^P(:,`!
M``!6BUPD&.B1O?__@\00@_C_=*F#[`S_="08BWPD&(G[Z+>___^+7"0PC8>8
MH?__B=KHAN[__XD<).@^^O__@\00Z?#]__^-M@````")V#'_ZPZ-M"8`````
MC78`BT2\3(7`='F)\H/'`>CN[/__A<!TZH`X`'3E@^P,4(M<)!CH*+W__X/$
M$(7`=-&)Q>F2^___@^P(4/]T)!B+1"0D_S"+7"0<C8-,H___Z6S]__^-="8`
MD(/L#%")1"0<Z+OY__^+1"0<BUPD&(D$).C;O/__B40D,(/$$.E9_?__@^P,
M:@V+?"08B?N-KWZB___HZ;___XE$)""#Q!#I3?O__XUT)@"0BT0D%(L`B40D
M&.G7_?__:@)J_VKNBW0D,%:+?"08B?OHD[___X/$#&H&C80D-`$``(E$)!Q0
M5NA,OO__@\00@+PD+`$```!U#H"\)"T!``!##X09!0``:@!J`&H`_W0D,(M<
M)!CH3K___\>$)(`````!(T5GQX0DA`````````#'A"2(````B:O-[\>$)(P`
M````````QX0DD````/[<NIC'A"24`````````,>$))@```!V5#(0QX0DG```
M``````#'A"2@````\.'2P\>$)*0`````````QX0DJ`````````#'A"2L````
M`````,>$)+``````````QX0DM`````````#'A"3X`````````(/$$(V$)*@`
M``")1"0LC78`@^P$:`"```#_="0<_W0D,(M<)!CH3[W__X/$$(G&A<`/CML!
M``")\(GQB70D&(N\)*````"9P>$#N``````#C"28````.XPDF````!N$))P`
M``")5"0<BZPDI````',&@\<!@]4`BU0D'(M$)!B)C"28````QX0DG```````
M```/K-`=P>H=`?B)A"2@````BX0DZ````!'JB90DI````(7`#X10`0``O4``
M```IQ3GN#T[N`T0D+(/L!%7_="0<4(M<)!CH#KW__XN$)/@````!Z(F$)/@`
M``"#Q!"#^$`/A1K___^+1"0H*>X#;"04Z)/!__^#_C\/CMT"``"#[D")]XET
M)!B)[L'O!HU?`<'C!@'KBVPD*(L&@\9`B80DJ````(M&Q(F$)*P```"+1LB)
MA"2P````BT;,B80DM````(M&T(F$)+@```"+1M2)A"2\````BT;8B80DP```
M`(M&W(F$),0```"+1N")A"3(````BT;DB80DS````(M&Z(F$)-````"+1NR)
MA"34````BT;PB80DV````(M&](F$)-P```"+1OB)A"3@````BT;\B80DY```
M`(GHZ,?`__\Y\P^%3____XMT)!C!YP8I_FI$5E/_="0XBUPD&.CENO__B;0D
M^````(/$$.D._O__C;8`````BVPD%.GT_O__@^P,_W0D,(M<)!CHU[K__XN$
M)*@```"+E"2L````BZPDJ````(N<)+`````/K-`#@^`_#\T/RXU(`<:$!+@`
M``"`@\00@_DX#XZ3`0``BU0D++A``````<HIR(G!=`TQP,8$`@"#P`$YR'+U
MBT0D*.@2P/__BWPD++D.````,<#SJXM$)"B)K"3D````C;0D\````(V\)"L!
M``")G"3@````Z."___^+5"1PB7PD%(V,)`,!``")3"08B<V+3"0(B?</RHF4
M).\```"+5"1XC8F?HO__#[9$)',/RHF4)/,```"+E"2`````B<X/RHF4)/<`
M``"+E"2(````#\J)E"3[````BY0DD`````_*B90D_P```.D+````C70F`)`/
MM@>#QP&#[`P/ML!05FK_:@%5BUPD*(/%`NB9N___@\0@.6PD%'78BUPD",:$
M)"L!````C8/PHO__4(V#O*+___]T)!S_="08_W0D&%!J_VH!_W0D/.A=N___
M@\0@Z6SZ__^+1"04BU`$A=(/A(;Y__^#[`Q2BWPD&(G[B50D).B3M___@\00
M@_@##X9G^?__BU0D%+D%````C;^WHO__C70"_/.F#Y?`'`"$P`]%5"08B50D
M&.D]^?__B>OI\/W__[HX````BT0D+#'V*<H!R(/Z!',BA=(/A(7^___&``#V
MP@(/A'G^__\QR6:)3!#^Z6W^__]FD(U(!,<``````(/A_,=$$/P`````*<@!
MT(/@_(/X!`^"1_[__X/@_#'2B301@\($.<)R]NDS_O__@+PD+@$``$$/A=GZ
M__^`O"0O`0``0P^%R_K__X"\)#`!``!(#X6]^O__@+PD,0$``$4/A:_Z__]J
M`FK_:L:+;"0P58M\)!B)^^CZN?__@\0,:BF+="0<5E7HNKC__XV'\*+__U"-
MA[RB__]6_W0D*/]T)"A0:O]J`?]T)$SH!KK__X/$,.D5^?__Z+D$``"-M"8`
M````9I!55U93Z)>\__^!PX=C``"#[#AEH10```")1"0H,<"+NP0!``#_-^AU
MM___7?\WB<;H:[?__P^V5FB(4&F-1"0HB40D'(G"C8/3H?__Z/_E__^#Q!"%
MP'0)@#@Q#X2O`@``Z'KP__^#[`S_-^@PM___C9/JHO__:@MJ`5)0Z$^W__^#
MQ""%P`^$_@```(M`#(.[>`4```&++XM`&(E$)`@/CN<````Q]NL]C;0F````
M`(M"#(/L"(U6`5"+@W0%``#_-)")5"04Z'2W__^#Q!"+BW@%``"%P'5O@\8"
MBU0D!#GQB=9^8H/L#%7HL;;__VH`5O]T)"!0Z$2X__^#Q""%P'0]BQ"++XM"
M""4`!"``/0`$``!TFHE4)`2#[`Q5Z'VV__]J`FH`BU0D'%)0Z!ZV__^++X/$
M(.EW____C70F`(N+>`4``(LOC4'_.?!U/8/Y`7XXB>B^`0```(ML)`CK"8VT
M)@````"+!X/L#(/&`5#H*K;__UI955#H0;7__X/$$#FS>`4``'_>BR^#[`Q5
MZ`NV__^-D^^B__]J`VH!4E#H*K;__X/$((G&A<!T,HM`#(/L#(LH_S?HXK7_
M_X/$#(V3\:+__U)54.AQM?__BT8,@\00BS#V1@I`#X5G`0``@^P,_S?HM;7_
M_XV3]J+__VH#:@%24.C4M?__@\0@B<:%P'0VBU0D#(V#H:'__^@\Y/__B<6%
MP`^$`@$``(M&#(/L#(LP_S?H<[7__X/$#%564.@(M?__@\00@^P,_S?H6[7_
M_X/$#(V3^*+__VH!4E#H";;__XG&6/\WZ#^U__^#Q`R-DPVC__]25E#HSK3_
M_UK_-^@FM?__BU0D',9`:0"-@YBA___HP^/__X/$$(G&B8-\!0``A<!T1(/L
M"&C``0``5NCFL___@\00C5`!@_H!=@F#^!$/A:H```"+1"0<93,%%`````^%
ME````(/$+%M>7UW#C;0F`````&:0@^P,_[-T!0``Z%+Q__^#Q!")QHF#?`4`
M`(7`=9^#[`R-@]RC__]0Z&2U__^-="8`@'@!``^$3/W__^E"_?__D(N#=`4`
M`(/L#(LHBT8,BS#_-^AIM/__B>J)\.C0Z/__@\00Z?/^__^#[`S_-^A.M/__
M65U64.B%M?__@\00Z7[^___H2`$``%"+@W0%``!6_S"-@P"D__]0Z/*T__]F
MD%?H<````(''"F```%93BUPD$(/L#%/H5>S__X/$$`^V$(G&A-)T&8VT)@``
M``!FD(/``8#Z+P^V$`]$\(32=?#HZ^[__X7;=!^%P'0;@#L`=!:Y!````(V_
MI*+___.F#Y?`'`"$P'0$6UY?PXG86UY?Z0KF__^+/"3#9I!FD&:04^B:N/__
M@<.*7P``@^P(C8,T`0``A<!T'XL`4/]T)!S_="0<_W0D'.A3L___@\086\.-
MM@`````QP.O?9I!FD%575E/H5[C__X'#1U\``(/L#(ML)""-L]S^___HJ['_
M_XV#V/[__RG&P?X"A?9T)3'_C;8`````@^P$_W0D+/]T)"Q5_Y2[V/[__X/'
M`8/$$#G^=>.#Q`Q;7E]=PXUV`//#9I!FD&:09I!FD&:09I!3Z.JW__^!P]I>
M``"#[`CH3++__U.#[`CHT[?__X'#PUX``(/$"%O#`P````$``@`E<R\E<P`O
M<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O
M`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(
M10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$
M25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%.
M/0`Q`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`
M5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E
M<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%2
M1U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T`
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS
M:2YC````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`[
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U
M,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE
M(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R
M(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D
M;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D
M;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA
M<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E
M="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D
M:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F
M9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E
M="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0[
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@
M)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R
M971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M
M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE
M;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@
M>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV
M;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R
M:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N
M86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[
M7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@
M(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S
M+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@
M(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?
M0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M
M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T
M96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO
M<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET
M92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N
M=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=6
M7S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH``1L#.^@````<````*'+__P0!``#X=?__*`$```AV__^T#```F'G_
M_SP!``!(HO__@`$``!BC___X`0``J*/__S`"``#XI?__L`(``'BG__]H`P``
M"*C__[@#``#XJ/__5`0``#BI__^$!```F*G__]`$``"HJ?__Y`0``+BK___,
M!0``Z*O__^`%``#8K/__8`8``*BN__^8!@``**___[P&``!HK___\`8``#BP
M__]<!P``^+O___@*``!XO___;`P``.Z____\#```^+___Q`-```XP/__1`T`
M`)C`__^0#0``J,#__Z0-```4``````````%Z4@`!?`@!&PP$!(@!```@````
M'````!QQ___0`P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````,AT__\0
M`````````$````!4````5'C__Z8H````00X(A0)$#@R'`T$.$(8$00X4@P5&
M#J`&`X\H"@X40<,.$$'&#@Q!QPX(0<4.!$$+````=````)@```#`H/__Q```
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)!#C1!#CA$#CQ!#D!(#C!7"@X4
M0\,.$$'&#@Q!QPX(0<4.!$(+;@H.%$/##A!!Q@X,0<<."$'%#@1$"T,.%$/#
M#A!#Q@X,0<<."$'%#@0`-````!`!```8H?__@@````!,#@B'`D$.#(8#0PX0
M@P1##B`"9@H.$$'##@Q!Q@X(0<<.!$$+``!\````2`$``'"A__]"`@```$$.
M"(4"0PX,AP-!#A"&!$,.%(,%3@Y,5PY02`Y`6@Y,0PY02`Y``DT.3$T.4$@.
M0`)Q"@X40<,.$$'&#@Q!QPX(0<4.!$<+`EP.3$$.4%(.0$L.1$@.2$D.3$4.
M4%`.0&,.2$$.3$$.4%`.0````+0```#(`0``0*/__WX!````00X(A0)!#@R'
M`T$.$(8$0PX4@P51#J`!;`H.%$'##A!!Q@X,0<<."$'%#@1)"T,.K`%!#K`!
M2`Z@`5H.K`%!#K`!2`Z@`5H.K`%!#K`!:PZL`4$.J`%%#JP!00ZP`40.M`%"
M#K@!0@Z\`4$.P`%(#J0!1`ZH`4$.K`%"#K`!2`Z@`5<.K`%!#K`!2`Z@`4,.
MK`%!#K`!2`Z@`6L.K`%!#K`!4`Z@`0!,````@`(```BD__^"`````$$."(8"
M0PX,@P-.#H0!40Z(`4$.C`%"#I`!2`Z``6(.B`%"#HP!00Z0`4@.@`%?"@X,
M0<,."$'&#@1!"P```)@```#0`@``2*3__^$`````00X(A0)!#@R'`T,.$(8$
M00X4@P51#L0(6`[("$L.S`A!#M`(2`[`"&$.Q`A!#L@(0@[,"$$.T`A(#L`(
M2P[,"$$.T`A&#M0(00[8"$$.W`A!#N`(2`[`"%8*#A1!PPX00<8.#$''#@A!
MQ0X$20M3#LP(00[0"$@.Q`A$#L@(00[,"$$.T`A(#L`(`"P```!L`P``G*3_
M_SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"<`P``
MK*3__U,`````00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$<.&$(.'$$.($$.
M)$<.*$<.+$$.,$@.#$'##@A!Q@X$```0````Z`,``,"D__\#`````````.0`
M``#\`P``O*3__P4"````00X(A0)!#@R'`T$.$(8$00X4@P51#J`)<PZH"4(.
MK`E##K`)2`Z@"7$*#A1!PPX00<8.#$''#@A!Q0X$1@M##JP)1`ZP"48.K`E!
M#J@)3PZL"4$.L`E(#J`)9@ZH"4$.K`E!#K`)2`Z@"4L.K`E!#K`)2`Z@"7(.
MI`E*#J@)00ZL"4<.L`E!#K0)10ZX"4(.O`E(#L`)2`ZD"44.J`E!#JP)0@ZP
M"4@.H`E6#J@)1`ZL"4(.L`E(#J`)`DD.J`E"#JP)00ZP"4@.H`E4#JP)00ZP
M"4@.H`D0````Y`0``.2E__\I`````````'P```#X!````*;__^@`````00X(
MA@)!#@R#`TX.$%@.'$$.($@.$'<.'$<.($@.$$,*#@Q!PPX(0<8.!$0+80X4
M00X800X<1PX@2`X010H.#$'##@A!Q@X$1PM##AQ"#B!(#A!/"@X,0<,."$'&
M#@1""T,.#$/##@A!Q@X$````-````'@%``!PIO__T`$```!!#@B'`D$.#(8#
M00X0@P1.#D`#8`$*#A!!PPX,0<8."$''#@1$"P`@````L`4```BH__]V````
M`$$."(,"3@X@9PH."$'##@1)"P`P````U`4``&2H__\W`````$$."(,"3@X0
M2`X<00X@2`X020H."$'##@1&"T,."$/##@0`:`````@&``!PJ/__Q@````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)'"@X40<,.$$'&#@Q!QPX(0<4.!$,+
M0PXX00X\00Y`2`XP1PX\00Y`7@XT20XX00X\1PY`00Y$0@Y(0@Y,00Y02`XP
MF`,``'0&``#4J/__MPL```!,#@B%`D$.#(<#00X0A@1!#A2#!48.T(("`L8.
MW(("00[@@@)>#M""`FT.W(("1`[@@@)!#N2"`D(.Z(("0@[L@@)!#O""`D\.
MT(("?P[<@@)!#N""`DP.T(("<@[<@@)!#N""`DP.T(("4@[<@@)!#N""`DP.
MT(("?0[<@@),#N""`EL.Y(("00[H@@)+#NR"`DD.\(("00[T@@)"#OB"`D(.
M_(("00Z`@P)(#MB"`D4.W(("00[@@@)(#M""`E@.U(("20[8@@)$#MR"`D(.
MX(("3`[0@@))#MR"`D0.X(("1@[D@@)+#NB"`D@.[(("0@[P@@)(#M""`F8*
M#A1!PPX00<8.#$''#@A!Q0X$1`MY#MR"`D0.X(("7P[0@@)+#MR"`D$.X(("
M2@[<@@)!#MB"`D$.W(("1@[@@@),#M""`DL.W(("10[@@@),#M""`@)*#MB"
M`D(.W(("1`[@@@)0#M""`FL.U(("00[8@@)0#MR"`D0.X(("00[D@@)"#NB"
M`D(.[(("1`[P@@)(#M""`FH.W(("1`[@@@)!#N2"`D$.Z(("1`[L@@)$#O""
M`D$.](("0@[X@@)"#OR"`D$.@(,"3`[0@@)##MB"`D4.W(("00[@@@),#M""
M`D@.W(("1`[@@@)G#M""`GD.W(("00[@@@),#M""`DX*#MB"`D$.W(("1`[@
M@@)&#N2"`E0+0P[<@@)!#N""`F`.T(("2`[<@@)"#N""`E@.T(("6P[4@@)"
M#MB"`D(.W(("10[@@@).#M2"`D(.V(("3`[<@@)!#N""`D@.T(("6@[4@@)"
M#MB"`D(.W(("1`[@@@("L0[0@@)1#M2"`D4.V(("1`[<@@)$#N""`DP.T(("
M`I\.U(("00[8@@)$#MR"`D$.X(("7`[0@@("]P[4@@)!#MB"`D$.W(("1`[@
M@@)3#M""`E<.W(("1`[@@@)^#M""`@+C#MR"`D0.X(("00[D@@)"#NB"`D(.
M[(("00[P@@)/#M""`ED.U(("2@[8@@)$#MR"`D0.X(("00[D@@)"#NB"`D(.
M[(("1`[P@@)(#M""`E<.W(("00[@@@)2#M""`@+B#M2"`D(.V(("0@[<@@)%
M#N""`DX.U(("0@[8@@)%#MR"`D$.X(("3`[D@@)'#NB"`D0.[(("1`[P@@)!
M#O2"`D(.^(("0@[\@@)$#H"#`D@.T(("<`$``!`*``#XL/__?@,```!!#@B%
M`D$.#(<#00X0A@1!#A2#!4X.3%0.4$8.3$(.4&8.0%4.3$(.4$T.5$(.6$$.
M7$$.8$@.0'(.2$0.3$D.4$P.0%H.3$$.4$<.5$$.6$0.7$$.8$@.0%X.3$$.
M4$<.5$(.6$4.7$$.8$H.0'8.3$0.4$8.3$$.2$$.3$$.4$@.0$T.3$$.4$T.
M5$(.6$$.7$$.8$@.0$P.3$0.4$@.1$<.2$$.3$$.4$L.0$\.3$(.4$T.5$(.
M6$$.7$$.8$@.0&4.3$0.4$@.1$$.2$$.3$$.4$@.0$,.3$(.4$@.1$@.2$$.
M3$$.4$@.3$(.4$@.1$<.2$$.3$$.4$8.3$(.4%L.0$\.2$4.3$$.4$@.0&4*
M#A1!PPX00<8.#$''#@A!Q0X$2@M#"@Y,1@Y02`Y`3PY,1PY020M9#DQ)#E!1
M#D!(#DQ"#E!&#DQ!#DA!#DQ!#E!(#D!+#D1'#DA"#DQ'#E``1````(0+```$
ML___=@````!!#@B'`DP.#(8#00X0@P1'#AQ!#B!(#A`"2PK##@Q!Q@X(0<<.
M!$$+0\,.#$'&#@A!QPX$````1````,P+``!,:?__3`(```!$#`$`1Q`%`G4`
M0Q`'`G5\1!`&`G5X$`,"=71,#P-U<`8#>@$*P0P!`$'#0<9!QT'%0PP$!$$+
M$````!0,``#JLO__!``````````P````*`P``."R__\\`````$$."(,"3@X0
M30X41`X81`X<1`X@2`X(0<,.!$<.$(,"````2````%P,``#LLO__70````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$0.*$0.+$$.,$T.($<.%$'##A!!
MQ@X,0<<."$'%#@0``!````"H#````+/__P(`````````&````+P,``#\LO__
M%`````!!#@B#`DX.$```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#0&```
M@!@```$````!`````0```-`!```!````VP$```$```#E`0```0```#0"```!
M````A`,```P```!,$0``#0````1@```9````J+T``!L````$````&@```*R]
M```<````!````/7^_V^H`0``!0```-0(```&````A`(```H```#4!```"P``
M`!`````5``````````,```#0O@```@```.`!```4````$0```!<```!L#P``
M$0```.0.```2````B````!,````(````'@````@```#[__]O`0``"/[__V]T
M#@``____;P(```#P__]OJ`T``/K__V\%````````````````````````````
M`````````````````````````````+"]`````````````(81``"6$0``IA$`
M`+81``#&$0``UA$``.81``#V$0``!A(``!82```F$@``-A(``$82``!6$@``
M9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82``#F$@``]A(```83```6
M$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,``)83``"F$P``MA,``,83
M``#6$P``YA,``/83```&%```%A0``"84```V%```1A0``%84``!F%```=A0`
M`(84``"6%```IA0``+84``#&%```UA0``.84``#V%```!A4``!85```F%0``
M-A4``````````````````````````````````````````````````%`5````
M````````````````````!,```/____\48P``1T-#.B`H1&5B:6%N(#@N,BXP
M+3@I(#@N,BXP`$=#0SH@*$1E8FEA;B`V+C0N,"TW*2`V+C0N,"`R,#$W,#DR
M,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N
M8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L
M="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M```````````````+`````0````(```!4`0``5`$```T```````````````$`
M````````$P````<````"````9`$``&0!```@```````````````$````````
M`"$````'`````@```(0!``"$`0``)```````````````!``````````T````
M]O__;P(```"H`0``J`$``-P````%``````````0````$````/@````L````"
M````A`(``(0"``!0!@``!@````$````$````$````$8````#`````@```-0(
M``#4"```U`0``````````````0````````!.````____;P(```"H#0``J`T`
M`,H````%``````````(````"````6P```/[__V\"````=`X``'0.``!P````
M!@````(````$`````````&H````)`````@```.0.``#D#@``B`````4`````
M````!`````@```!S````"0```$(```!L#P``;`\``.`!```%````%@````0`
M```(````?`````$````&````3!$``$P1```C```````````````$````````
M`'<````!````!@```'`1``!P$0``T`,`````````````$`````0```""````
M`0````8```!`%0``0!4``!````````````````@````(````BP````$````&
M````4!4``%`5``"T2@`````````````0`````````)$````!````!@````1@
M```$8```%```````````````!`````````"7`````0````(````88```&&``
M`#`_``````````````0`````````GP````$````"````2)\``$B?``#L````
M```````````$`````````*T````!`````@```#2@```TH```V`P`````````
M````!`````````"W````#@````,```"HO0``J*T```0```````````````0`
M```$````PP````\````#````K+T``*RM```$```````````````$````!```
M`,\````&`````P```+"]``"PK0``(`$```8`````````!`````@```"&````
M`0````,```#0O@``T*X``#`!``````````````0````$````V`````$````#
M`````,````"P```0```````````````$`````````-X````(`````P```"#`
M```0L```-`0`````````````(`````````#C`````0```#``````````$+``
M`$$```````````````$````!`````0````,``````````````%&P``#L````
0```````````!````````````
